==> sparkautomapper.fhir-0.2.1-py3-none-any.whl: spark_auto_mapper_fhir/backbone_elements/related_claim_backbone_element.py <==
from typing import Optional, TYPE_CHECKING
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.id import FhirId

from spark_auto_mapper_fhir.backbone_elements.fhir_backbone_element_base import FhirBackboneElementBase

if TYPE_CHECKING:
    from spark_auto_mapper_fhir.complex_types.codeableConcept import CodeableConcept
    from spark_auto_mapper_fhir.valuesets.related_claim_relationship import RelatedClaimRelationshipCode
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier
    from spark_auto_mapper_fhir.resources.claim import Claim
    from spark_auto_mapper_fhir.complex_types.reference import Reference


class RelatedClaimBackboneElement(FhirBackboneElementBase):
    def __init__(
        self,
        id_: Optional[FhirId] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        claim: Optional['Reference[Claim]'] = None,
        relationship: Optional['CodeableConcept[RelatedClaimRelationshipCode]'
                               ] = None,
        reference: Optional['Identifier'] = None
    ):
        """
        RelatedClaimBackboneElement Resource in FHIR
        https://hl7.org/FHIR/claim-definitions.html#Claim.related
        Prior or corollary claims

        :param claim: Reference to the related claim
        :param relationship: How the reference claim is related.
                            https://hl7.org/FHIR/valueset-related-claim-relationship.html
        :param reference: 	File or case reference
        """
        super().__init__(
            id_=id_,
            extension=extension,
            claim=claim,
            relationship=relationship,
            reference=reference
        )

==> sparkautomapper.fhir-0.2.21b4-py3-none-any.whl: spark_auto_mapper_fhir/backbone_elements/related_claim_backbone_element.py <==
from typing import Optional, TYPE_CHECKING
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.id import FhirId

from spark_auto_mapper_fhir.backbone_elements.fhir_backbone_element_base import (
    FhirBackboneElementBase,
)

if TYPE_CHECKING:
    from spark_auto_mapper_fhir.complex_types.codeableConcept import CodeableConcept
    from spark_auto_mapper_fhir.valuesets.related_claim_relationship import (
        RelatedClaimRelationshipCode,
    )
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier
    from spark_auto_mapper_fhir.resources.claim import Claim
    from spark_auto_mapper_fhir.complex_types.reference import Reference


class RelatedClaimBackboneElement(FhirBackboneElementBase):
    def __init__(
        self,
        id_: Optional[FhirId] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        claim: Optional["Reference[Claim]"] = None,
        relationship: Optional["CodeableConcept[RelatedClaimRelationshipCode]"] = None,
        reference: Optional["Identifier"] = None,
    ):
        """
        RelatedClaimBackboneElement Resource in FHIR
        https://hl7.org/FHIR/claim-definitions.html#Claim.related
        Prior or corollary claims

        :param claim: Reference to the related claim
        :param relationship: How the reference claim is related.
                            https://hl7.org/FHIR/valueset-related-claim-relationship.html
        :param reference: 	File or case reference
        """
        super().__init__(
            id_=id_,
            extension=extension,
            claim=claim,
            relationship=relationship,
            reference=reference,
        )
